@@ -2,7 +2,7 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps(p) {
 }
-function _aws_cdk_aws_apigatewayv2_authorizers_UserPoolAuthorizerProps(p) {
+function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps(p) {
     if (p == null)
         return;
     visitedObjects.add(p);
@@ -18,10 +18,10 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps(p) {
         _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p.responseTypes);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
-}
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer(p) {
 }
+function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
+}
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer(p) {
 }
 function print(name, deprecationMessage) {
@@ -39,5 +39,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_UserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer };
+module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer };
 module.exports.DeprecationError = DeprecationError;
