@@ -50,9 +50,9 @@ In the example below, all routes will require the `manage:books` scope present i
 from aws_cdk.aws_apigatewayv2_authorizers import HttpJwtAuthorizer
 
 
-authorizer = HttpJwtAuthorizer(
-    jwt_audience=["3131231"],
-    jwt_issuer="https://test.us.auth0.com"
+issuer = "https://test.us.auth0.com"
+authorizer = HttpJwtAuthorizer("DefaultAuthorizer", issuer,
+    jwt_audience=["3131231"]
 )
 
 api = apigwv2.HttpApi(self, "HttpApi",
@@ -73,12 +73,12 @@ The example below showcases default authorization, along with route authorizatio
 
 ```python
 from aws_cdk.aws_apigatewayv2_authorizers import HttpJwtAuthorizer
-from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
 
-authorizer = HttpJwtAuthorizer(
-    jwt_audience=["3131231"],
-    jwt_issuer="https://test.us.auth0.com"
+issuer = "https://test.us.auth0.com"
+authorizer = HttpJwtAuthorizer("DefaultAuthorizer", issuer,
+    jwt_audience=["3131231"]
 )
 
 api = apigwv2.HttpApi(self, "HttpApi",
@@ -87,34 +87,26 @@ api = apigwv2.HttpApi(self, "HttpApi",
 )
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books",
     methods=[apigwv2.HttpMethod.GET]
 )
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIdIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books/{id}",
     methods=[apigwv2.HttpMethod.GET]
 )
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books",
     methods=[apigwv2.HttpMethod.POST],
     authorization_scopes=["write:books"]
 )
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("LoginIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/login",
     methods=[apigwv2.HttpMethod.POST],
     authorizer=apigwv2.HttpNoneAuthorizer()
@@ -139,20 +131,18 @@ Clients that fail authorization are presented with either 2 responses:
 
 ```python
 from aws_cdk.aws_apigatewayv2_authorizers import HttpJwtAuthorizer
-from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
 
-authorizer = HttpJwtAuthorizer(
-    jwt_audience=["3131231"],
-    jwt_issuer="https://test.us.auth0.com"
+issuer = "https://test.us.auth0.com"
+authorizer = HttpJwtAuthorizer("BooksAuthorizer", issuer,
+    jwt_audience=["3131231"]
 )
 
 api = apigwv2.HttpApi(self, "HttpApi")
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books",
     authorizer=authorizer
 )
@@ -169,23 +159,17 @@ pools as authorizer](https://docs.aws.amazon.com/apigateway/latest/developerguid
 ```python
 import aws_cdk.aws_cognito as cognito
 from aws_cdk.aws_apigatewayv2_authorizers import HttpUserPoolAuthorizer
-from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
 
 user_pool = cognito.UserPool(self, "UserPool")
-user_pool_client = user_pool.add_client("UserPoolClient")
 
-authorizer = HttpUserPoolAuthorizer(
-    user_pool=user_pool,
-    user_pool_clients=[user_pool_client]
-)
+authorizer = HttpUserPoolAuthorizer("BooksAuthorizer", user_pool)
 
 api = apigwv2.HttpApi(self, "HttpApi")
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books",
     authorizer=authorizer
 )
@@ -199,24 +183,20 @@ Lambda authorizers depending on their response, fall into either two types - Sim
 
 ```python
 from aws_cdk.aws_apigatewayv2_authorizers import HttpLambdaAuthorizer, HttpLambdaResponseType
-from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
 
 # This function handles your auth logic
 # auth_handler is of type Function
 
 
-authorizer = HttpLambdaAuthorizer(
-    authorizer_name="lambda-authorizer",
-    response_types=[HttpLambdaResponseType.SIMPLE],  # Define if returns simple and/or iam response
-    handler=auth_handler
+authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
+    response_types=[HttpLambdaResponseType.SIMPLE]
 )
 
 api = apigwv2.HttpApi(self, "HttpApi")
 
 api.add_routes(
-    integration=HttpProxyIntegration(
-        url="https://get-books-proxy.myproxy.internal"
-    ),
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
     path="/books",
     authorizer=authorizer
 )
@@ -253,20 +233,18 @@ class HttpJwtAuthorizer(
     Example::
 
         from aws_cdk.aws_apigatewayv2_authorizers import HttpJwtAuthorizer
-        from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+        from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
         
         
-        authorizer = HttpJwtAuthorizer(
-            jwt_audience=["3131231"],
-            jwt_issuer="https://test.us.auth0.com"
+        issuer = "https://test.us.auth0.com"
+        authorizer = HttpJwtAuthorizer("BooksAuthorizer", issuer,
+            jwt_audience=["3131231"]
         )
         
         api = apigwv2.HttpApi(self, "HttpApi")
         
         api.add_routes(
-            integration=HttpProxyIntegration(
-                url="https://get-books-proxy.myproxy.internal"
-            ),
+            integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
             path="/books",
             authorizer=authorizer
         )
@@ -274,28 +252,30 @@ class HttpJwtAuthorizer(
 
     def __init__(
         self,
+        id: builtins.str,
+        jwt_issuer: builtins.str,
         *,
         jwt_audience: typing.Sequence[builtins.str],
-        jwt_issuer: builtins.str,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
-        '''
+        '''(experimental) Initialize a JWT authorizer to be bound with HTTP route.
+
+        :param id: The id of the underlying construct.
+        :param jwt_issuer: The base domain of the identity provider that issues JWT.
         :param jwt_audience: (experimental) A list of the intended recipients of the JWT. A valid JWT must provide an aud that matches at least one entry in this list.
-        :param jwt_issuer: (experimental) The base domain of the identity provider that issues JWT.
-        :param authorizer_name: (experimental) The name of the authorizer. Default: 'JwtAuthorizer'
+        :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
 
         :stability: experimental
         '''
         props = HttpJwtAuthorizerProps(
             jwt_audience=jwt_audience,
-            jwt_issuer=jwt_issuer,
             authorizer_name=authorizer_name,
             identity_source=identity_source,
         )
 
-        jsii.create(self.__class__, self, [props])
+        jsii.create(self.__class__, self, [id, jwt_issuer, props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -323,7 +303,6 @@ class HttpJwtAuthorizer(
     jsii_struct_bases=[],
     name_mapping={
         "jwt_audience": "jwtAudience",
-        "jwt_issuer": "jwtIssuer",
         "authorizer_name": "authorizerName",
         "identity_source": "identitySource",
     },
@@ -333,15 +312,13 @@ class HttpJwtAuthorizerProps:
         self,
         *,
         jwt_audience: typing.Sequence[builtins.str],
-        jwt_issuer: builtins.str,
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''(experimental) Properties to initialize HttpJwtAuthorizer.
 
         :param jwt_audience: (experimental) A list of the intended recipients of the JWT. A valid JWT must provide an aud that matches at least one entry in this list.
-        :param jwt_issuer: (experimental) The base domain of the identity provider that issues JWT.
-        :param authorizer_name: (experimental) The name of the authorizer. Default: 'JwtAuthorizer'
+        :param authorizer_name: (experimental) The name of the authorizer. Default: - same value as ``id`` passed in the constructor
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
 
         :stability: experimental
@@ -349,27 +326,24 @@ class HttpJwtAuthorizerProps:
         Example::
 
             from aws_cdk.aws_apigatewayv2_authorizers import HttpJwtAuthorizer
-            from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+            from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
             
             
-            authorizer = HttpJwtAuthorizer(
-                jwt_audience=["3131231"],
-                jwt_issuer="https://test.us.auth0.com"
+            issuer = "https://test.us.auth0.com"
+            authorizer = HttpJwtAuthorizer("BooksAuthorizer", issuer,
+                jwt_audience=["3131231"]
             )
             
             api = apigwv2.HttpApi(self, "HttpApi")
             
             api.add_routes(
-                integration=HttpProxyIntegration(
-                    url="https://get-books-proxy.myproxy.internal"
-                ),
+                integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
                 path="/books",
                 authorizer=authorizer
             )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "jwt_audience": jwt_audience,
-            "jwt_issuer": jwt_issuer,
         }
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
@@ -388,21 +362,11 @@ class HttpJwtAuthorizerProps:
         assert result is not None, "Required property 'jwt_audience' is missing"
         return typing.cast(typing.List[builtins.str], result)
 
-    @builtins.property
-    def jwt_issuer(self) -> builtins.str:
-        '''(experimental) The base domain of the identity provider that issues JWT.
-
-        :stability: experimental
-        '''
-        result = self._values.get("jwt_issuer")
-        assert result is not None, "Required property 'jwt_issuer' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def authorizer_name(self) -> typing.Optional[builtins.str]:
         '''(experimental) The name of the authorizer.
 
-        :default: 'JwtAuthorizer'
+        :default: - same value as ``id`` passed in the constructor
 
         :stability: experimental
         '''
@@ -444,24 +408,20 @@ class HttpLambdaAuthorizer(
     Example::
 
         from aws_cdk.aws_apigatewayv2_authorizers import HttpLambdaAuthorizer, HttpLambdaResponseType
-        from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+        from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
         
         # This function handles your auth logic
         # auth_handler is of type Function
         
         
-        authorizer = HttpLambdaAuthorizer(
-            authorizer_name="lambda-authorizer",
-            response_types=[HttpLambdaResponseType.SIMPLE],  # Define if returns simple and/or iam response
-            handler=auth_handler
+        authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
+            response_types=[HttpLambdaResponseType.SIMPLE]
         )
         
         api = apigwv2.HttpApi(self, "HttpApi")
         
         api.add_routes(
-            integration=HttpProxyIntegration(
-                url="https://get-books-proxy.myproxy.internal"
-            ),
+            integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
             path="/books",
             authorizer=authorizer
         )
@@ -469,16 +429,19 @@ class HttpLambdaAuthorizer(
 
     def __init__(
         self,
-        *,
-        authorizer_name: builtins.str,
+        id: builtins.str,
         handler: aws_cdk.aws_lambda.IFunction,
+        *,
+        authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
         response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
         results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> None:
-        '''
-        :param authorizer_name: (experimental) The name of the authorizer.
-        :param handler: (experimental) The lambda function used for authorization.
+        '''(experimental) Initialize a lambda authorizer to be bound with HTTP route.
+
+        :param id: The id of the underlying construct.
+        :param handler: -
+        :param authorizer_name: (experimental) Friendly authorizer name. Default: - same value as ``id`` passed in the constructor.
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
         :param response_types: (experimental) The types of responses the lambda can return. If HttpLambdaResponseType.SIMPLE is included then response format 2.0 will be used. Default: [HttpLambdaResponseType.IAM]
         :param results_cache_ttl: (experimental) How long APIGateway should cache the results. Max 1 hour. Disable caching by setting this to ``Duration.seconds(0)``. Default: Duration.minutes(5)
@@ -487,13 +450,12 @@ class HttpLambdaAuthorizer(
         '''
         props = HttpLambdaAuthorizerProps(
             authorizer_name=authorizer_name,
-            handler=handler,
             identity_source=identity_source,
             response_types=response_types,
             results_cache_ttl=results_cache_ttl,
         )
 
-        jsii.create(self.__class__, self, [props])
+        jsii.create(self.__class__, self, [id, handler, props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -521,7 +483,6 @@ class HttpLambdaAuthorizer(
     jsii_struct_bases=[],
     name_mapping={
         "authorizer_name": "authorizerName",
-        "handler": "handler",
         "identity_source": "identitySource",
         "response_types": "responseTypes",
         "results_cache_ttl": "resultsCacheTtl",
@@ -531,16 +492,14 @@ class HttpLambdaAuthorizerProps:
     def __init__(
         self,
         *,
-        authorizer_name: builtins.str,
-        handler: aws_cdk.aws_lambda.IFunction,
+        authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
         response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
         results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> None:
         '''(experimental) Properties to initialize HttpTokenAuthorizer.
 
-        :param authorizer_name: (experimental) The name of the authorizer.
-        :param handler: (experimental) The lambda function used for authorization.
+        :param authorizer_name: (experimental) Friendly authorizer name. Default: - same value as ``id`` passed in the constructor.
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
         :param response_types: (experimental) The types of responses the lambda can return. If HttpLambdaResponseType.SIMPLE is included then response format 2.0 will be used. Default: [HttpLambdaResponseType.IAM]
         :param results_cache_ttl: (experimental) How long APIGateway should cache the results. Max 1 hour. Disable caching by setting this to ``Duration.seconds(0)``. Default: Duration.minutes(5)
@@ -550,32 +509,27 @@ class HttpLambdaAuthorizerProps:
         Example::
 
             from aws_cdk.aws_apigatewayv2_authorizers import HttpLambdaAuthorizer, HttpLambdaResponseType
-            from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+            from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
             
             # This function handles your auth logic
             # auth_handler is of type Function
             
             
-            authorizer = HttpLambdaAuthorizer(
-                authorizer_name="lambda-authorizer",
-                response_types=[HttpLambdaResponseType.SIMPLE],  # Define if returns simple and/or iam response
-                handler=auth_handler
+            authorizer = HttpLambdaAuthorizer("BooksAuthorizer", auth_handler,
+                response_types=[HttpLambdaResponseType.SIMPLE]
             )
             
             api = apigwv2.HttpApi(self, "HttpApi")
             
             api.add_routes(
-                integration=HttpProxyIntegration(
-                    url="https://get-books-proxy.myproxy.internal"
-                ),
+                integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
                 path="/books",
                 authorizer=authorizer
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
-            "authorizer_name": authorizer_name,
-            "handler": handler,
-        }
+        self._values: typing.Dict[str, typing.Any] = {}
+        if authorizer_name is not None:
+            self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
             self._values["identity_source"] = identity_source
         if response_types is not None:
@@ -584,24 +538,15 @@ class HttpLambdaAuthorizerProps:
             self._values["results_cache_ttl"] = results_cache_ttl
 
     @builtins.property
-    def authorizer_name(self) -> builtins.str:
-        '''(experimental) The name of the authorizer.
+    def authorizer_name(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Friendly authorizer name.
+
+        :default: - same value as ``id`` passed in the constructor.
 
         :stability: experimental
         '''
         result = self._values.get("authorizer_name")
-        assert result is not None, "Required property 'authorizer_name' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def handler(self) -> aws_cdk.aws_lambda.IFunction:
-        '''(experimental) The lambda function used for authorization.
-
-        :stability: experimental
-        '''
-        result = self._values.get("handler")
-        assert result is not None, "Required property 'handler' is missing"
-        return typing.cast(aws_cdk.aws_lambda.IFunction, result)
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def identity_source(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -687,23 +632,17 @@ class HttpUserPoolAuthorizer(
 
         import aws_cdk.aws_cognito as cognito
         from aws_cdk.aws_apigatewayv2_authorizers import HttpUserPoolAuthorizer
-        from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
+        from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
         
         
         user_pool = cognito.UserPool(self, "UserPool")
-        user_pool_client = user_pool.add_client("UserPoolClient")
         
-        authorizer = HttpUserPoolAuthorizer(
-            user_pool=user_pool,
-            user_pool_clients=[user_pool_client]
-        )
+        authorizer = HttpUserPoolAuthorizer("BooksAuthorizer", user_pool)
         
         api = apigwv2.HttpApi(self, "HttpApi")
         
         api.add_routes(
-            integration=HttpProxyIntegration(
-                url="https://get-books-proxy.myproxy.internal"
-            ),
+            integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
             path="/books",
             authorizer=authorizer
         )
@@ -711,31 +650,33 @@ class HttpUserPoolAuthorizer(
 
     def __init__(
         self,
+        id: builtins.str,
+        pool: aws_cdk.aws_cognito.IUserPool,
         *,
-        user_pool: aws_cdk.aws_cognito.IUserPool,
-        user_pool_clients: typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient],
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+        user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
         user_pool_region: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''
-        :param user_pool: (experimental) The associated user pool.
-        :param user_pool_clients: (experimental) The user pool clients that should be used to authorize requests with the user pool.
-        :param authorizer_name: (experimental) The name of the authorizer. Default: 'UserPoolAuthorizer'
+        '''(experimental) Initialize a Cognito user pool authorizer to be bound with HTTP route.
+
+        :param id: The id of the underlying construct.
+        :param pool: The user pool to use for authorization.
+        :param authorizer_name: (experimental) Friendly name of the authorizer. Default: - same value as ``id`` passed in the constructor
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+        :param user_pool_clients: (experimental) The user pool clients that should be used to authorize requests with the user pool. Default: - a new client will be created for the given user pool
         :param user_pool_region: (experimental) The AWS region in which the user pool is present. Default: - same region as the Route the authorizer is attached to.
 
         :stability: experimental
         '''
-        props = UserPoolAuthorizerProps(
-            user_pool=user_pool,
-            user_pool_clients=user_pool_clients,
+        props = HttpUserPoolAuthorizerProps(
             authorizer_name=authorizer_name,
             identity_source=identity_source,
+            user_pool_clients=user_pool_clients,
             user_pool_region=user_pool_region,
         )
 
-        jsii.create(self.__class__, self, [props])
+        jsii.create(self.__class__, self, [id, pool, props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -759,97 +700,65 @@ class HttpUserPoolAuthorizer(
 
 
 @jsii.data_type(
-    jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.UserPoolAuthorizerProps",
+    jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpUserPoolAuthorizerProps",
     jsii_struct_bases=[],
     name_mapping={
-        "user_pool": "userPool",
-        "user_pool_clients": "userPoolClients",
         "authorizer_name": "authorizerName",
         "identity_source": "identitySource",
+        "user_pool_clients": "userPoolClients",
         "user_pool_region": "userPoolRegion",
     },
 )
-class UserPoolAuthorizerProps:
+class HttpUserPoolAuthorizerProps:
     def __init__(
         self,
         *,
-        user_pool: aws_cdk.aws_cognito.IUserPool,
-        user_pool_clients: typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient],
         authorizer_name: typing.Optional[builtins.str] = None,
         identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+        user_pool_clients: typing.Optional[typing.Sequence[aws_cdk.aws_cognito.IUserPoolClient]] = None,
         user_pool_region: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''(experimental) Properties to initialize UserPoolAuthorizer.
+        '''(experimental) Properties to initialize HttpUserPoolAuthorizer.
 
-        :param user_pool: (experimental) The associated user pool.
-        :param user_pool_clients: (experimental) The user pool clients that should be used to authorize requests with the user pool.
-        :param authorizer_name: (experimental) The name of the authorizer. Default: 'UserPoolAuthorizer'
+        :param authorizer_name: (experimental) Friendly name of the authorizer. Default: - same value as ``id`` passed in the constructor
         :param identity_source: (experimental) The identity source for which authorization is requested. Default: ['$request.header.Authorization']
+        :param user_pool_clients: (experimental) The user pool clients that should be used to authorize requests with the user pool. Default: - a new client will be created for the given user pool
         :param user_pool_region: (experimental) The AWS region in which the user pool is present. Default: - same region as the Route the authorizer is attached to.
 
         :stability: experimental
+        :exampleMetadata: fixture=_generated
 
         Example::
 
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_apigatewayv2_authorizers as apigatewayv2_authorizers
             import aws_cdk.aws_cognito as cognito
-            from aws_cdk.aws_apigatewayv2_authorizers import HttpUserPoolAuthorizer
-            from aws_cdk.aws_apigatewayv2_integrations import HttpProxyIntegration
             
+            # user_pool_client is of type UserPoolClient
             
-            user_pool = cognito.UserPool(self, "UserPool")
-            user_pool_client = user_pool.add_client("UserPoolClient")
-            
-            authorizer = HttpUserPoolAuthorizer(
-                user_pool=user_pool,
-                user_pool_clients=[user_pool_client]
-            )
-            
-            api = apigwv2.HttpApi(self, "HttpApi")
-            
-            api.add_routes(
-                integration=HttpProxyIntegration(
-                    url="https://get-books-proxy.myproxy.internal"
-                ),
-                path="/books",
-                authorizer=authorizer
+            http_user_pool_authorizer_props = apigatewayv2_authorizers.HttpUserPoolAuthorizerProps(
+                authorizer_name="authorizerName",
+                identity_source=["identitySource"],
+                user_pool_clients=[user_pool_client],
+                user_pool_region="userPoolRegion"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
-            "user_pool": user_pool,
-            "user_pool_clients": user_pool_clients,
-        }
+        self._values: typing.Dict[str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
             self._values["identity_source"] = identity_source
+        if user_pool_clients is not None:
+            self._values["user_pool_clients"] = user_pool_clients
         if user_pool_region is not None:
             self._values["user_pool_region"] = user_pool_region
 
-    @builtins.property
-    def user_pool(self) -> aws_cdk.aws_cognito.IUserPool:
-        '''(experimental) The associated user pool.
-
-        :stability: experimental
-        '''
-        result = self._values.get("user_pool")
-        assert result is not None, "Required property 'user_pool' is missing"
-        return typing.cast(aws_cdk.aws_cognito.IUserPool, result)
-
-    @builtins.property
-    def user_pool_clients(self) -> typing.List[aws_cdk.aws_cognito.IUserPoolClient]:
-        '''(experimental) The user pool clients that should be used to authorize requests with the user pool.
-
-        :stability: experimental
-        '''
-        result = self._values.get("user_pool_clients")
-        assert result is not None, "Required property 'user_pool_clients' is missing"
-        return typing.cast(typing.List[aws_cdk.aws_cognito.IUserPoolClient], result)
-
     @builtins.property
     def authorizer_name(self) -> typing.Optional[builtins.str]:
-        '''(experimental) The name of the authorizer.
+        '''(experimental) Friendly name of the authorizer.
 
-        :default: 'UserPoolAuthorizer'
+        :default: - same value as ``id`` passed in the constructor
 
         :stability: experimental
         '''
@@ -867,6 +776,19 @@ class UserPoolAuthorizerProps:
         result = self._values.get("identity_source")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def user_pool_clients(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_cognito.IUserPoolClient]]:
+        '''(experimental) The user pool clients that should be used to authorize requests with the user pool.
+
+        :default: - a new client will be created for the given user pool
+
+        :stability: experimental
+        '''
+        result = self._values.get("user_pool_clients")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cognito.IUserPoolClient]], result)
+
     @builtins.property
     def user_pool_region(self) -> typing.Optional[builtins.str]:
         '''(experimental) The AWS region in which the user pool is present.
@@ -885,7 +807,7 @@ class UserPoolAuthorizerProps:
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return "UserPoolAuthorizerProps(%s)" % ", ".join(
+        return "HttpUserPoolAuthorizerProps(%s)" % ", ".join(
             k + "=" + repr(v) for k, v in self._values.items()
         )
 
@@ -897,7 +819,7 @@ __all__ = [
     "HttpLambdaAuthorizerProps",
     "HttpLambdaResponseType",
     "HttpUserPoolAuthorizer",
-    "UserPoolAuthorizerProps",
+    "HttpUserPoolAuthorizerProps",
 ]
 
 publication.publish()
